<?php
/*
Plugin Name: Page Menu Editor
Plugin URI: http://www.stuffbysarah.net/wordpress-plugins/page-menu-editor/
Description: Allows you to customise the title attribute and menu label of each page link in wp_list_pages() or wp_page_menu().
Author: Sarah Anderson
Version: 1.9.1
Author URI: http://www.stuffbysarah.net/
*/

add_filter('wp_list_pages','pta_filter', 1);

/* the main wp_list_pages() filter */
function pta_filter_callback($matches) {
	global $wpdb;
	
	if ($matches[1] && !empty($matches[1])) $postID = $matches[1];
	
	if (empty($postID)) $postID = get_option("page_on_front");

	// now identifier is the post ID
	$title_attrib = stripslashes(get_post_meta($postID, 'title_attrib', true));
	$menulabel = stripslashes(get_post_meta($postID, 'menulabel', true));
	
	if (empty($menulabel)) $menulabel = $matches[4];
	
	if ($title_attrib == "%%pagetitle%%") $title_attrib = get_the_title($postID);
	elseif ($title_attrib == "%%menulabel%%") $title_attrib = $menulabel;

	if (!empty($title_attrib) || !empty($menulabel)) :
		$filtered = '<li class="page_item page-item-'.$postID.$matches[2].'"><a href="'.$matches[3].'" title="'.$title_attrib.'">'.$menulabel.'</a>';
	else :
		$filtered = '<li class="page_item page-item-'.$postID.$matches[2].'"><a href="'.$matches[3].'">'.$menulabel.'</a>';
	endif;
	
	return $filtered;
	
}

function pta_filter($content) {
	// escape the blog's base URL
	$url = preg_replace(array('/\//', '/\./', '/\-/'), array('\/', '\.', '\-'), get_option('siteurl'));
  
	$pattern = '@<li class="page_item page-item-(\d+)([^\"]*)"><a href=\"([^\"]+)" title="([^\"]+)">(.*?)</a>@is';

	return preg_replace_callback($pattern, "pta_filter_callback", $content);
}

add_action('edit_post', 'pta_update');
add_action('save_post', 'pta_update');
add_action('publish_post', 'pta_update');

/* Use the admin_menu action to define the custom boxes */
add_action('admin_menu', 'pta_add_custom_box');

/* Adds a custom section to the "advanced" Post and Page edit screens */
function pta_add_custom_box() {
	if( function_exists( 'add_meta_box' )) {
    	add_meta_box( 'pgmenueditor', 'Page Menu Editor', 
                'pta_inner_custom_box', 'page', 'advanced', 'high' );
	}
}
   
/* Prints the inner fields for the custom post/page section */
function pta_inner_custom_box() {

  // Use nonce for verification

  echo '<input type="hidden" name="myplugin_noncename" id="myplugin_noncename" value="' . 
    wp_create_nonce( plugin_basename(__FILE__) ) . '" />';

  // The actual fields for data entry
  global $post;
	$custom_pta_value = stripslashes(get_post_meta($post->ID, 'title_attrib', true));
	$menulabel = stripslashes(get_post_meta($post->ID, 'menulabel', true));
?>
        <div class="inside">
        <label for="menulabel">Page Menu Label: </label>
        <input type="text" name="menulabel" value="<?php echo $menulabel ?>" id="menulabel" style="width:95%" />
        <p>Specify a menu label for the page link in the navigation.</p>
        
		<label for="title_attrib">Page Link Title Attribute: </label>
        <input type="text" name="title_attrib" value="<?php echo $custom_pta_value ?>" id="title_attrib" style="width:95%" />
        <p>Specify a title attribute for the page link in the navigation to help with usability and accessibility.</p>
        <p><em>(Use %%pagetitle%% to use the page title or %%menulabel%% to use the menu label).</em></p>
        </div>
<?php
}


function pta_update($id) {
	// verify this came from the our screen and with proper authorization,
	// because save_post can be triggered at other times

	if ( !wp_verify_nonce( $_POST['myplugin_noncename'], plugin_basename(__FILE__) )) {
    	return $post_id;
	}

	if ( 'page' == $_POST['post_type'] ) {
    	if ( !current_user_can( 'edit_page', $post_id ))
		return $post_id;
	} else {
		return $post_id;
	}

	$value = $_POST['title_attrib'];
	$label = $_POST['menulabel'];

	if (!empty($value)) {
		$meta_value = get_post_meta($id, 'title_attrib', true);

		if(!empty($meta_value)) {
			update_post_meta($id, 'title_attrib', $value);
		} else {
			add_post_meta($id, 'title_attrib', $value, true);
		}
	} else {
		delete_post_meta($id, 'title_attrib');
	}
	
	if (!empty($label)) {
		$meta_value = get_post_meta($id, 'menulabel', true);

		if(!empty($meta_value)) {
			update_post_meta($id, 'menulabel', $label);
		} else {
			add_post_meta($id, 'menulabel', $label, true);
		}
	} else {
		delete_post_meta($id, 'menulabel');
	}
}


/* All of this just added in to allow easy migration to AIOSP which uses the same code above as it doesn't migrate settings over */
if (get_option('pta_aiosp_chk') !='1'){
	if (function_exists('aioseop_get_version')) :
		add_action('admin_notices', 'pta_upg_notice');
	endif;
}

function pta_upg_notice(){
	echo '<div class="error fade"><p>Please visit the <a href="options-general.php?page=page-menu-editor.php">Settings Page for the Page Menu Editor</a></p></div>';
}

add_action('admin_menu', 'pta_menu');	
function pta_menu() {
	add_options_page('Page Menu Editor', 'Page Menu Editor', 'update_plugins', 'pg-menu-editor-upgrade', 'pta_upgrade');
}

function pta_upgrade() {

	if (isset($_POST['pta_migrate'])) :
		global $wpdb;
		$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_aioseop_titleatr' WHERE meta_key = 'title_attrib'");
		$wpdb->query("UPDATE $wpdb->postmeta SET meta_key = '_aioseop_menulabel' WHERE meta_key = 'menulabel'");
		update_option('pta_aiosp_chk', 1);
		
		echo "<div class='fade'><p>The migration is complete. You can remove the Page Menu Editor plugin now.</p></div>\n";
	endif;

	?>
	<div class="wrap">
	<h2>Page Menu Editor Upgrade</h2>
	<?php if (function_exists('aioseop_get_version')) : ?>
    <p>It appears that you are running a version of the All In One SEO Pack. Since version 1.6.4 the code and functionality provided by
    the Page Menu Editor plugin is incorporated into the AIOSEO Pack plugin and therefore the Page Menu Editor plugin is no longer needed.</p>
    <p>However, the settings do no migrate automatically, so to do this please click the button below. Once the settings have updated
    you can deactivated and remove the Page Menu Editor plugin.</p>
    
    <p>Please note: do not run this migration if your version of the All In One SEO Pack plugin is 1.6.3 or less.</p>
    
	<form id="ptamigrate" method="post" action="" class="form-table">
    	<div class="submit"><input type="submit" name="pta_migrate" value="Migrate Settings"/></div>
    </form>
    <?php else : ?>
    	<p>This is a migration page for users using the All In One SEO Pack plugin. You do not appear to be using that therefore can ignore this page!</p>
    <?php endif; ?>
    </div>    
<?php	
}
?>